/*
 * Copyright 2023 Tadashi G. Takaoka
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "text_common.h"

namespace libasm {
namespace text {
namespace common {

// clang-format off
const char TEXT_NOP[]   PROGMEM = "NOP";
const char TEXT_ADD[]   PROGMEM = "ADD";
const char TEXT_INC[]   PROGMEM = "INC";
const char TEXT_AND[]   PROGMEM = "AND";
const char TEXT_RET[]   PROGMEM = "RET";
const char TEXT_DEC[]   PROGMEM = "DEC";
const char TEXT_JMP[]   PROGMEM = "JMP";
const char TEXT_SUB[]   PROGMEM = "SUB";
const char TEXT_POP[]   PROGMEM = "POP";
const char TEXT_OR[]    PROGMEM = "OR";
const char TEXT_XOR[]   PROGMEM = "XOR";
const char TEXT_PUSH[]  PROGMEM = "PUSH";
const char TEXT_NEG[]   PROGMEM = "NEG";
const char TEXT_CLR[]   PROGMEM = "CLR";
const char TEXT_ADC[]   PROGMEM = "ADC";
const char TEXT_CALL[]  PROGMEM = "CALL";
const char TEXT_RR[]    PROGMEM = "RR";
const char TEXT_LD[]    PROGMEM = "LD";
const char TEXT_LDA[]   PROGMEM = "LDA";
const char TEXT_DIV[]   PROGMEM = "DIV";
const char TEXT_SBC[]   PROGMEM = "SBC";
const char TEXT_RRC[]   PROGMEM = "RRC";
const char TEXT_RLC[]   PROGMEM = "RLC";
const char TEXT_OUT[]   PROGMEM = "OUT";
const char TEXT_MUL[]   PROGMEM = "MUL";
const char TEXT_JSR[]   PROGMEM = "JSR";
const char TEXT_JP[]    PROGMEM = "JP";
const char TEXT_IN[]    PROGMEM = "IN";
const char TEXT_HALT[]  PROGMEM = "HALT";
const char TEXT_EI[]    PROGMEM = "EI";
const char TEXT_DJNZ[]  PROGMEM = "DJNZ";
const char TEXT_DI[]    PROGMEM = "DI";
const char TEXT_DAA[]   PROGMEM = "DAA";
const char TEXT_CMP[]   PROGMEM = "CMP";
const char TEXT_SUBB[]  PROGMEM = "SUBB";
const char TEXT_ST[]    PROGMEM = "ST";
const char TEXT_SRL[]   PROGMEM = "SRL";
const char TEXT_ROR[]   PROGMEM = "ROR";
const char TEXT_ROL[]   PROGMEM = "ROL";
const char TEXT_RL[]    PROGMEM = "RL";
const char TEXT_ORI[]   PROGMEM = "ORI";
const char TEXT_JNC[]   PROGMEM = "JNC";
const char TEXT_COM[]   PROGMEM = "COM";
const char TEXT_BRA[]   PROGMEM = "BRA";
const char TEXT_BNE[]   PROGMEM = "BNE";
const char TEXT_BIT[]   PROGMEM = "BIT";
const char TEXT_BEQ[]   PROGMEM = "BEQ";
const char TEXT_BCS[]   PROGMEM = "BCS";
const char TEXT_BCC[]   PROGMEM = "BCC";
const char TEXT_SWI[]   PROGMEM = "SWI";
const char TEXT_STOP[]  PROGMEM = "STOP";
const char TEXT_STA[]   PROGMEM = "STA";
const char TEXT_SRA[]   PROGMEM = "SRA";
const char TEXT_RTS[]   PROGMEM = "RTS";
const char TEXT_ORA[]   PROGMEM = "ORA";
const char TEXT_NEGB[]  PROGMEM = "NEGB";
const char TEXT_MOV[]   PROGMEM = "MOV";
const char TEXT_LSR[]   PROGMEM = "LSR";
const char TEXT_LDX[]   PROGMEM = "LDX";
const char TEXT_LDI[]   PROGMEM = "LDI";
const char TEXT_LDD[]   PROGMEM = "LDD";
const char TEXT_JZ[]    PROGMEM = "JZ";
const char TEXT_JNZ[]   PROGMEM = "JNZ";
const char TEXT_JC[]    PROGMEM = "JC";
const char TEXT_EOR[]   PROGMEM = "EOR";
const char TEXT_CP[]    PROGMEM = "CP";
const char TEXT_CPL[]   PROGMEM = "CPL";
const char TEXT_BSR[]   PROGMEM = "BSR";
const char TEXT_BR[]    PROGMEM = "BR";
const char TEXT_BPL[]   PROGMEM = "BPL";
const char TEXT_BMI[]   PROGMEM = "BMI";
const char TEXT_BLS[]   PROGMEM = "BLS";
const char TEXT_BLO[]   PROGMEM = "BLO";
const char TEXT_BHS[]   PROGMEM = "BHS";
const char TEXT_BHI[]   PROGMEM = "BHI";
const char TEXT_BGE[]   PROGMEM = "BGE";
const char TEXT_ASL[]   PROGMEM = "ASL";
const char TEXT_ANDB[]  PROGMEM = "ANDB";
const char TEXT_ADDB[]  PROGMEM = "ADDB";
const char TEXT_TST[]   PROGMEM = "TST";
const char TEXT_SWAP[]  PROGMEM = "SWAP";
const char TEXT_SUBA[]  PROGMEM = "SUBA";
const char TEXT_STX[]   PROGMEM = "STX";
const char TEXT_STD[]   PROGMEM = "STD";
const char TEXT_SR[]    PROGMEM = "SR";
const char TEXT_SLA[]   PROGMEM = "SLA";
const char TEXT_RTI[]   PROGMEM = "RTI";
const char TEXT_RETI[]  PROGMEM = "RETI";
const char TEXT_ORB[]   PROGMEM = "ORB";
const char TEXT_LSL[]   PROGMEM = "LSL";
const char TEXT_LDB[]   PROGMEM = "LDB";
const char TEXT_JR[]    PROGMEM = "JR";
const char TEXT_INS[]   PROGMEM = "INS";
const char TEXT_INCB[]  PROGMEM = "INCB";
const char TEXT_DECB[]  PROGMEM = "DECB";
const char TEXT_CPI[]   PROGMEM = "CPI";
const char TEXT_CPD[]   PROGMEM = "CPD";
const char TEXT_COMB[]  PROGMEM = "COMB";
const char TEXT_COMA[]  PROGMEM = "COMA";
const char TEXT_CMPB[]  PROGMEM = "CMPB";
const char TEXT_CLRB[]  PROGMEM = "CLRB";
const char TEXT_CLI[]   PROGMEM = "CLI";
const char TEXT_CLC[]   PROGMEM = "CLC";
const char TEXT_BZ[]    PROGMEM = "BZ";
const char TEXT_BVS[]   PROGMEM = "BVS";
const char TEXT_BVC[]   PROGMEM = "BVC";
const char TEXT_BNZ[]   PROGMEM = "BNZ";
const char TEXT_BLT[]   PROGMEM = "BLT";
const char TEXT_BLE[]   PROGMEM = "BLE";
const char TEXT_BGT[]   PROGMEM = "BGT";
const char TEXT_ASR[]   PROGMEM = "ASR";
const char TEXT_ANDI[]  PROGMEM = "ANDI";
const char TEXT_ADDA[]  PROGMEM = "ADDA";
const char TEXT_XRI[]   PROGMEM = "XRI";
const char TEXT_XORB[]  PROGMEM = "XORB";
const char TEXT_XCH[]   PROGMEM = "XCH";
const char TEXT_WAIT[]  PROGMEM = "WAIT";
const char TEXT_TSTA[]  PROGMEM = "TSTA";
const char TEXT_TSET[]  PROGMEM = "TSET";
const char TEXT_SUBD[]  PROGMEM = "SUBD";
const char TEXT_STY[]   PROGMEM = "STY";
const char TEXT_STS[]   PROGMEM = "STS";
const char TEXT_STB[]   PROGMEM = "STB";
const char TEXT_SL[]    PROGMEM = "SL";
const char TEXT_SHR[]   PROGMEM = "SHR";
const char TEXT_SHL[]   PROGMEM = "SHL";
const char TEXT_SET[]   PROGMEM = "SET";
const char TEXT_SETB[]  PROGMEM = "SETB";
const char TEXT_SEI[]   PROGMEM = "SEI";
const char TEXT_SEC[]   PROGMEM = "SEC";
const char TEXT_SCF[]   PROGMEM = "SCF";
const char TEXT_SBCB[]  PROGMEM = "SBCB";
const char TEXT_RST[]   PROGMEM = "RST";
const char TEXT_RRL[]   PROGMEM = "RRL";
const char TEXT_RORA[]  PROGMEM = "RORA";
const char TEXT_ROLA[]  PROGMEM = "ROLA";
const char TEXT_RES[]   PROGMEM = "RES";
const char TEXT_null[]  PROGMEM = "";
const char TEXT_NOT[]   PROGMEM = "NOT";
const char TEXT_NEGA[]  PROGMEM = "NEGA";
const char TEXT_MPY[]   PROGMEM = "MPY";
const char TEXT_LSRA[]  PROGMEM = "LSRA";
const char TEXT_LSLA[]  PROGMEM = "LSLA";
const char TEXT_LDY[]   PROGMEM = "LDY";
const char TEXT_LDW[]   PROGMEM = "LDW";
const char TEXT_LDS[]   PROGMEM = "LDS";
const char TEXT_LDIR[]  PROGMEM = "LDIR";
const char TEXT_LDE[]   PROGMEM = "LDE";
const char TEXT_LDDR[]  PROGMEM = "LDDR";
const char TEXT_JNE[]   PROGMEM = "JNE";
const char TEXT_JLE[]   PROGMEM = "JLE";
const char TEXT_JB[]    PROGMEM = "JB";
const char TEXT_IRET[]  PROGMEM = "IRET";
const char TEXT_INX[]   PROGMEM = "INX";
const char TEXT_INCW[]  PROGMEM = "INCW";
const char TEXT_INCA[]  PROGMEM = "INCA";
const char TEXT_HLT[]   PROGMEM = "HLT";
const char TEXT_EXT[]   PROGMEM = "EXT";
const char TEXT_EX[]    PROGMEM = "EX";
const char TEXT_EORR[]  PROGMEM = "EORR";
const char TEXT_EORI[]  PROGMEM = "EORI";
const char TEXT_EORA[]  PROGMEM = "EORA";
const char TEXT_ENTER[] PROGMEM = "ENTER";
const char TEXT_DECW[]  PROGMEM = "DECW";
const char TEXT_DECA[]  PROGMEM = "DECA";
const char TEXT_DA[]    PROGMEM = "DA";
const char TEXT_CPX[]   PROGMEM = "CPX";
const char TEXT_CPIR[]  PROGMEM = "CPIR";
const char TEXT_CPDR[]  PROGMEM = "CPDR";
const char TEXT_CMPA[]  PROGMEM = "CMPA";
const char TEXT_CLRA[]  PROGMEM = "CLRA";
const char TEXT_CCF[]   PROGMEM = "CCF";
const char TEXT_BSET[]  PROGMEM = "BSET";
const char TEXT_BRN[]   PROGMEM = "BRN";
const char TEXT_B[]     PROGMEM = "B";
const char TEXT_BL[]    PROGMEM = "BL";
const char TEXT_BITB[]  PROGMEM = "BITB";
const char TEXT_BCLR[]  PROGMEM = "BCLR";
const char TEXT_ASRA[]  PROGMEM = "ASRA";
const char TEXT_ASLA[]  PROGMEM = "ASLA";
const char TEXT_ANI[]   PROGMEM = "ANI";
const char TEXT_ANDR[]  PROGMEM = "ANDR";
const char TEXT_ANDA[]  PROGMEM = "ANDA";
const char TEXT_AI[]    PROGMEM = "AI";
const char TEXT_ADI[]   PROGMEM = "ADI";
const char TEXT_ADDR[]  PROGMEM = "ADDR";
const char TEXT_ADDD[]  PROGMEM = "ADDD";
const char TEXT_ADDC[]  PROGMEM = "ADDC";
const char TEXT_ADCB[]  PROGMEM = "ADCB";
const char TEXT_XRL[]   PROGMEM = "XRL";
const char TEXT_XCHG[]  PROGMEM = "XCHG";
const char TEXT_XCHD[]  PROGMEM = "XCHD";
const char TEXT_WAI[]   PROGMEM = "WAI";
const char TEXT_TXS[]   PROGMEM = "TXS";
const char TEXT_TXA[]   PROGMEM = "TXA";
const char TEXT_TSX[]   PROGMEM = "TSX";
const char TEXT_TSTB[]  PROGMEM = "TSTB";
const char TEXT_TRAP[]  PROGMEM = "TRAP";
const char TEXT_TIM[]   PROGMEM = "TIM";
const char TEXT_TEST[]  PROGMEM = "TEST";
const char TEXT_TAX[]   PROGMEM = "TAX";
const char TEXT_SVC[]   PROGMEM = "SVC";
const char TEXT_SUBW[]  PROGMEM = "SUBW";
const char TEXT_SUBR[]  PROGMEM = "SUBR";
const char TEXT_SUBL[]  PROGMEM = "SUBL";
const char TEXT_SUBI[]  PROGMEM = "SUBI";
const char TEXT_SUBF[]  PROGMEM = "SUBF";
const char TEXT_SUBC[]  PROGMEM = "SUBC";
const char TEXT_SUBCB[] PROGMEM = "SUBCB";
const char TEXT_STR[]   PROGMEM = "STR";
const char TEXT_STC[]   PROGMEM = "STC";
const char TEXT_S[]     PROGMEM = "S";
const char TEXT_SM[]    PROGMEM = "SM";
const char TEXT_SMI[]   PROGMEM = "SMI";
const char TEXT_SLL[]   PROGMEM = "SLL";
const char TEXT_SJMP[]  PROGMEM = "SJMP";
const char TEXT_SEX[]   PROGMEM = "SEX";
const char TEXT_SEQ[]   PROGMEM = "SEQ";
const char TEXT_SEP[]   PROGMEM = "SEP";
const char TEXT_SD[]    PROGMEM = "SD";
const char TEXT_SBCD[]  PROGMEM = "SBCD";
const char TEXT_SBCA[]  PROGMEM = "SBCA";
const char TEXT_SBB[]   PROGMEM = "SBB";
const char TEXT_SAR[]   PROGMEM = "SAR";
const char TEXT_RRD[]   PROGMEM = "RRD";
const char TEXT_RRCA[]  PROGMEM = "RRCA";
const char TEXT_RRA[]   PROGMEM = "RRA";
const char TEXT_RORB[]  PROGMEM = "RORB";
const char TEXT_ROLB[]  PROGMEM = "ROLB";
const char TEXT_RLD[]   PROGMEM = "RLD";
const char TEXT_RLCA[]  PROGMEM = "RLCA";
const char TEXT_RLA[]   PROGMEM = "RLA";
const char TEXT_RETEM[] PROGMEM = "RETEM";
const char TEXT_REP[]   PROGMEM = "REP";
const char TEXT_RCF[]   PROGMEM = "RCF";
const char TEXT_PUSHF[] PROGMEM = "PUSHF";
const char TEXT_POPF[]  PROGMEM = "POPF";
const char TEXT_PEA[]   PROGMEM = "PEA";
const char TEXT_OUTS[]  PROGMEM = "OUTS";
const char TEXT_OUTI[]  PROGMEM = "OUTI";
const char TEXT_OUTD[]  PROGMEM = "OUTD";
const char TEXT_OTIR[]  PROGMEM = "OTIR";
const char TEXT_OTDR[]  PROGMEM = "OTDR";
const char TEXT_ORR[]   PROGMEM = "ORR";
const char TEXT_ORL[]   PROGMEM = "ORL";
const char TEXT_ORD[]   PROGMEM = "ORD";
const char TEXT_OIM[]   PROGMEM = "OIM";
const char TEXT_NOTB[]  PROGMEM = "NOTB";
const char TEXT_NEGX[]  PROGMEM = "NEGX";
const char TEXT_NEGD[]  PROGMEM = "NEGD";
const char TEXT_MVI[]   PROGMEM = "MVI";
const char TEXT_MULU[]  PROGMEM = "MULU";
const char TEXT_MULT[]  PROGMEM = "MULT";
const char TEXT_MULD[]  PROGMEM = "MULD";
const char TEXT_MULB[]  PROGMEM = "MULB";
const char TEXT_MOVX[]  PROGMEM = "MOVX";
const char TEXT_MOVSW[] PROGMEM = "MOVSW";
const char TEXT_MOVSB[] PROGMEM = "MOVSB";
const char TEXT_MOVD[]  PROGMEM = "MOVD";
const char TEXT_MOVB[]  PROGMEM = "MOVB";
const char TEXT_LST[]   PROGMEM = "LST";
const char TEXT_LSRD[]  PROGMEM = "LSRD";
const char TEXT_LSRB[]  PROGMEM = "LSRB";
const char TEXT_LSLD[]  PROGMEM = "LSLD";
const char TEXT_LSLB[]  PROGMEM = "LSLB";
const char TEXT_LR[]    PROGMEM = "LR";
const char TEXT_LJMP[]  PROGMEM = "LJMP";
const char TEXT_LI[]    PROGMEM = "LI";
const char TEXT_LEA[]   PROGMEM = "LEA";
const char TEXT_LDC[]   PROGMEM = "LDC";
const char TEXT_LDAR[]  PROGMEM = "LDAR";
const char TEXT_LCALL[] PROGMEM = "LCALL";
const char TEXT_LBGE[]  PROGMEM = "LBGE";
const char TEXT_JPO[]   PROGMEM = "JPO";
const char TEXT_JPE[]   PROGMEM = "JPE";
const char TEXT_JNO[]   PROGMEM = "JNO";
const char TEXT_JNB[]   PROGMEM = "JNB";
const char TEXT_JLT[]   PROGMEM = "JLT";
const char TEXT_JL[]    PROGMEM = "JL";
const char TEXT_JH[]    PROGMEM = "JH";
const char TEXT_JGT[]   PROGMEM = "JGT";
const char TEXT_JGE[]   PROGMEM = "JGE";
const char TEXT_JE[]    PROGMEM = "JE";
const char TEXT_JBC[]   PROGMEM = "JBC";
const char TEXT_INY[]   PROGMEM = "INY";
const char TEXT_INSW[]  PROGMEM = "INSW";
const char TEXT_INSB[]  PROGMEM = "INSB";
const char TEXT_INIR[]  PROGMEM = "INIR";
const char TEXT_INI[]   PROGMEM = "INI";
const char TEXT_INDR[]  PROGMEM = "INDR";
const char TEXT_IND[]   PROGMEM = "IND";
const char TEXT_INCX[]  PROGMEM = "INCX";
const char TEXT_ILD[]   PROGMEM = "ILD";
const char TEXT_IDL[]   PROGMEM = "IDL";
const char TEXT_IDIV[]  PROGMEM = "IDIV";
const char TEXT_FLT[]   PROGMEM = "FLT";
const char TEXT_EXX[]   PROGMEM = "EXX";
const char TEXT_EXTSB[] PROGMEM = "EXTSB";
const char TEXT_EXTB[]  PROGMEM = "EXTB";
const char TEXT_EXIT[]  PROGMEM = "EXIT";
const char TEXT_EXG[]   PROGMEM = "EXG";
const char TEXT_EORB[]  PROGMEM = "EORB";
const char TEXT_EIM[]   PROGMEM = "EIM";
const char TEXT_DLD[]   PROGMEM = "DLD";
const char TEXT_DIVU[]  PROGMEM = "DIVU";
const char TEXT_DIVS[]  PROGMEM = "DIVS";
const char TEXT_DIVL[]  PROGMEM = "DIVL";
const char TEXT_DIVD[]  PROGMEM = "DIVD";
const char TEXT_DIVB[]  PROGMEM = "DIVB";
const char TEXT_DIS[]   PROGMEM = "DIS";
const char TEXT_DINT[]  PROGMEM = "DINT";
const char TEXT_DEY[]   PROGMEM = "DEY";
const char TEXT_DEX[]   PROGMEM = "DEX";
const char TEXT_DECX[]  PROGMEM = "DECX";
const char TEXT_DAS[]   PROGMEM = "DAS";
const char TEXT_DAD[]   PROGMEM = "DAD";
const char TEXT_CPY[]   PROGMEM = "CPY";
const char TEXT_CPU[]   PROGMEM = "CPU";
const char TEXT_C[]     PROGMEM = "C";
const char TEXT_COMW[]  PROGMEM = "COMW";
const char TEXT_COMD[]  PROGMEM = "COMD";
const char TEXT_CMPW[]  PROGMEM = "CMPW";
const char TEXT_CMPSW[] PROGMEM = "CMPSW";
const char TEXT_CMPS[]  PROGMEM = "CMPS";
const char TEXT_CMPSB[] PROGMEM = "CMPSB";
const char TEXT_CM[]    PROGMEM = "CM";
const char TEXT_CMPL[]  PROGMEM = "CMPL";
const char TEXT_CMPF[]  PROGMEM = "CMPF";
const char TEXT_CMPD[]  PROGMEM = "CMPD";
const char TEXT_CMC[]   PROGMEM = "CMC";
const char TEXT_CLV[]   PROGMEM = "CLV";
const char TEXT_CLD[]   PROGMEM = "CLD";
const char TEXT_CI[]    PROGMEM = "CI";
const char TEXT_CB[]    PROGMEM = "CB";
const char TEXT_CALR[]  PROGMEM = "CALR";
const char TEXT_CALLN[] PROGMEM = "CALLN";
const char TEXT_BTST[]  PROGMEM = "BTST";
const char TEXT_BT[]    PROGMEM = "BT";
const char TEXT_BRSET[] PROGMEM = "BRSET";
const char TEXT_BRCLR[] PROGMEM = "BRCLR";
const char TEXT_BP[]    PROGMEM = "BP";
const char TEXT_BOR[]   PROGMEM = "BOR";
const char TEXT_BM[]    PROGMEM = "BM";
const char TEXT_BITA[]  PROGMEM = "BITA";
const char TEXT_BAND[]  PROGMEM = "BAND";
const char TEXT_ASRB[]  PROGMEM = "ASRB";
const char TEXT_ASLD[]  PROGMEM = "ASLD";
const char TEXT_ASLB[]  PROGMEM = "ASLB";
const char TEXT_A[]     PROGMEM = "A";
const char TEXT_ANL[]   PROGMEM = "ANL";
const char TEXT_ANDD[]  PROGMEM = "ANDD";
const char TEXT_AM[]    PROGMEM = "AM";
const char TEXT_AIM[]   PROGMEM = "AIM";
const char TEXT_ADDW[]  PROGMEM = "ADDW";
const char TEXT_ADDL[]  PROGMEM = "ADDL";
const char TEXT_ADDI[]  PROGMEM = "ADDI";
const char TEXT_ADDF[]  PROGMEM = "ADDF";
const char TEXT_ADDCB[] PROGMEM = "ADDCB";
const char TEXT_ADCA[]  PROGMEM = "ADCA";
const char TEXT_ABX[]   PROGMEM = "ABX";
const char TEXT_ABS[]   PROGMEM = "ABS";

const char TEXT_CPU_8080[]   PROGMEM = "8080";
const char TEXT_CPU_8085[]   PROGMEM = "8085";
const char TEXT_CPU_V30EMU[] PROGMEM = "V30EMU";

const char TEXT_REG_A[]   PROGMEM = "A";
const char TEXT_REG_SP[]  PROGMEM = "SP";
const char TEXT_REG_PC[]  PROGMEM = "PC";
const char TEXT_REG_E[]   PROGMEM = "E";
const char TEXT_REG_D[]   PROGMEM = "D";
const char TEXT_REG_C[]   PROGMEM = "C";
const char TEXT_REG_H[]   PROGMEM = "H";
const char TEXT_REG_B[]   PROGMEM = "B";
const char TEXT_REG_S[]   PROGMEM = "S";
const char TEXT_REG_R7[]  PROGMEM = "R7";
const char TEXT_REG_R6[]  PROGMEM = "R6";
const char TEXT_REG_R5[]  PROGMEM = "R5";
const char TEXT_REG_R4[]  PROGMEM = "R4";
const char TEXT_REG_R3[]  PROGMEM = "R3";
const char TEXT_REG_R2[]  PROGMEM = "R2";
const char TEXT_REG_R1[]  PROGMEM = "R1";
const char TEXT_REG_R0[]  PROGMEM = "R0";
const char TEXT_REG_P2[]  PROGMEM = "P2";
const char TEXT_REG_L[]   PROGMEM = "L";
const char TEXT_REG_I[]   PROGMEM = "I";
const char TEXT_REG_HL[]  PROGMEM = "HL";
const char TEXT_REG_W[]   PROGMEM = "W";
const char TEXT_REG_T[]   PROGMEM = "T";
const char TEXT_REG_PSW[] PROGMEM = "PSW";
const char TEXT_REG_P[]   PROGMEM = "P";
const char TEXT_REG_P3[]  PROGMEM = "P3";
const char TEXT_REG_P1[]  PROGMEM = "P1";
const char TEXT_REG_P0[]  PROGMEM = "P0";
const char TEXT_REG_IY[]  PROGMEM = "IY";
const char TEXT_REG_IX[]  PROGMEM = "IX";
const char TEXT_REG_F1[]  PROGMEM = "F1";
const char TEXT_REG_F0[]  PROGMEM = "F0";
const char TEXT_REG_DE[]  PROGMEM = "DE";
const char TEXT_REG_BC[]  PROGMEM = "BC";
const char TEXT_REG_AF[]  PROGMEM = "AF";
const char TEXT_REG_AFP[] PROGMEM = "AF'";

const char TEXT_CC_Z[]   PROGMEM = "Z";
const char TEXT_CC_NZ[]  PROGMEM = "NZ";
const char TEXT_CC_NC[]  PROGMEM = "NC";
const char TEXT_CC_LT[]  PROGMEM = "LT";
const char TEXT_CC_GT[]  PROGMEM = "GT";
const char TEXT_CC_EQ[]  PROGMEM = "EQ";
const char TEXT_CC_C[]   PROGMEM = "C";
const char TEXT_CC_ULT[] PROGMEM = "ULT";
const char TEXT_CC_ULE[] PROGMEM = "ULE";
const char TEXT_CC_UGT[] PROGMEM = "UGT";
const char TEXT_CC_UGE[] PROGMEM = "UGE";
const char TEXT_CC_T[]   PROGMEM = "";
const char TEXT_CC_PL[]  PROGMEM = "PL";
const char TEXT_CC_OV[]  PROGMEM = "OV";
const char TEXT_CC_NOV[] PROGMEM = "NOV";
const char TEXT_CC_NE[]  PROGMEM = "NE";
const char TEXT_CC_MI[]  PROGMEM = "MI";
const char TEXT_CC_LE[]  PROGMEM = "LE";
const char TEXT_CC_GE[]  PROGMEM = "GE";
const char TEXT_CC_F[]   PROGMEM = "F";
const char TEXT_CC_P[]   PROGMEM = "P";
const char TEXT_CC_PO[]  PROGMEM = "PO";
const char TEXT_CC_PE[]  PROGMEM = "PE";
const char TEXT_CC_M[]   PROGMEM = "M";

const char TEXT_FN_ADDR[] PROGMEM = "ADDR";
const char TEXT_FN_H[]    PROGMEM = "H";
const char TEXT_FN_L[]    PROGMEM = "L";

const char TEXT_dADDR[]  PROGMEM = ".addr";
const char TEXT_dALIGN[] PROGMEM = ".align";
const char TEXT_dASCII[] PROGMEM = ".ascii";
const char TEXT_dBYTE[]  PROGMEM = ".byte";
const char TEXT_dDBYTE[] PROGMEM = ".dbyte";
const char TEXT_dequal[] PROGMEM = ".=";
const char TEXT_dLONG[]  PROGMEM = ".long";
const char TEXT_dORG[]   PROGMEM = ".org";
const char TEXT_dSTRING[] PROGMEM = ".string";
const char TEXT_dWORD[]  PROGMEM = ".word";
const char TEXT_ALIGN[] PROGMEM = "align";
const char TEXT_BYTE[]  PROGMEM = "byte";
const char TEXT_DATA[]  PROGMEM = "data";
const char TEXT_DB[]    PROGMEM = "db";
const char TEXT_DCB[]   PROGMEM = "dcb";
const char TEXT_DCL[]   PROGMEM = "dcl";
const char TEXT_DC[]    PROGMEM = "dc";
const char TEXT_DCW[]   PROGMEM = "dcw";
const char TEXT_DD[]    PROGMEM = "dd";
const char TEXT_DEFB[]  PROGMEM = "defb";
const char TEXT_DEFL[]  PROGMEM = "defl";
const char TEXT_DEFM[]  PROGMEM = "defm";
const char TEXT_DEFS[]  PROGMEM = "defs";
const char TEXT_DEFW[]  PROGMEM = "defw";
const char TEXT_DL[]    PROGMEM = "dl";
const char TEXT_DSB[]   PROGMEM = "dsb";
const char TEXT_DSL[]   PROGMEM = "dsl";
const char TEXT_DS[]    PROGMEM = "ds";
const char TEXT_DSW[]   PROGMEM = "dsw";
const char TEXT_DW[]    PROGMEM = "dw";
const char TEXT_FCB[]   PROGMEM = "fcb";
const char TEXT_FCC[]   PROGMEM = "fcc";
const char TEXT_FDB[]   PROGMEM = "fdb";
const char TEXT_ORG[]   PROGMEM = "org";
const char TEXT_RMB[]   PROGMEM = "rmb";

// clang-format on

}  // namespace common
}  // namespace text
}  // namespace libasm

// Local Variables:
// mode: c++
// c-basic-offset: 4
// tab-width: 4
// End:
// vim: set ft=cpp et ts=4 sw=4:
